@@ -55,12 +55,6 @@
 #include "sensors-plugin.h"
 
 
-/*
- * Tooltips to display for any part of this plugin
- */
-extern GtkTooltips *tooltips;
-
-
 static void
 sensors_set_bar_size (GtkWidget *bar, int size, int orientation)
 {
@@ -295,6 +289,7 @@ sensors_add_graphical_display (t_sensors *sensors)
     gtk_label_set_markup (GTK_LABEL(sensors->panel_label_text), text);
     g_free (text);
 
+    gtk_container_set_border_width (GTK_CONTAINER(sensors->widget_sensors), 0);
     for (chipNum=0; chipNum < sensors->num_sensorchips; chipNum++) {
         chip = (t_chip *) g_ptr_array_index(sensors->chips, chipNum);
         g_assert (chip != NULL);
@@ -354,7 +349,6 @@ sensors_add_graphical_display (t_sensors *sensors)
                 panel->databox = databox;
                 sensors->panels[chipNum][feature] = (GtkWidget*) panel;
 
-                gtk_container_set_border_width (GTK_CONTAINER(sensors->widget_sensors), 0);
                 gtk_box_pack_start (GTK_BOX (sensors->widget_sensors),
                                     databox, FALSE, FALSE, INNER_BORDER);
             }
@@ -392,6 +386,8 @@ sensors_add_tacho_display (t_sensors *sensors)
     gtk_label_set_markup (GTK_LABEL(sensors->panel_label_text), text);
     g_free (text);
 
+    
+    gtk_container_set_border_width (GTK_CONTAINER(sensors->widget_sensors), 0);
     for (chipNum=0; chipNum < sensors->num_sensorchips; chipNum++) {
         chip = (t_chip *) g_ptr_array_index(sensors->chips, chipNum);
         g_assert (chip != NULL);
@@ -437,8 +433,6 @@ sensors_add_tacho_display (t_sensors *sensors)
                 sensors->tachos[chipNum][feature] = (GtkWidget*) tacho;
                 DBG("8");
 
-                gtk_container_set_border_width (GTK_CONTAINER(sensors->widget_sensors), 0);
-                DBG("9");
                 gtk_box_pack_start (GTK_BOX (sensors->widget_sensors),
                                     tacho, TRUE, TRUE, INNER_BORDER);
                 DBG("10");
@@ -771,7 +765,7 @@ static gboolean
 sensors_create_tooltip (gpointer data)
 {
     t_sensors *sensors;
-    GtkWidget *widget;
+    //GtkWidget *widget;
     int i, index_feature, res;
     double sensorFeature;
     gboolean first, prependedChipName;
@@ -785,7 +779,7 @@ sensors_create_tooltip (gpointer data)
     TRACE ("data!=NULL");
 
     sensors = (t_sensors *) data;
-    widget = sensors->eventbox;
+    //widget = sensors->eventbox;
     myToolTipText = g_strdup (_("No sensors selected!"));
     first = TRUE;
 
@@ -853,13 +847,9 @@ sensors_create_tooltip (gpointer data)
         }
     }
 
-    if (!tooltips)
-      tooltips = gtk_tooltips_new();
-
-    /* #if GTK_VERSION < 2.11 */
-    gtk_tooltips_set_tip (tooltips, GTK_WIDGET(sensors->eventbox),
-                          myToolTipText, NULL);
-		DBG("tooltip text: %s.\n", myToolTipText);
+    gtk_widget_set_tooltip_text (GTK_WIDGET(sensors->eventbox), myToolTipText);
+    DBG("tooltip text: %s.\n", myToolTipText);
+    
     TRACE ("freeing myToolTipText");
     g_free (myToolTipText);
 
@@ -1023,7 +1013,7 @@ execute_command (GtkWidget *widget, GdkEventButton *event, gpointer data)
 
         g_return_val_if_fail ( sensors->exec_command, FALSE);
 
-				// screen NULL, command, terminal=no, startup=yes, error=NULL
+        // screen NULL, command, terminal=no, startup=yes, error=NULL
         xfce_spawn_command_line_on_screen (NULL, sensors->command_name, FALSE, TRUE, NULL);
 
         TRACE ("leaves execute_command with TRUE");
@@ -1037,31 +1027,6 @@ execute_command (GtkWidget *widget, GdkEventButton *event, gpointer data)
 }
 
 
-
-/* #if GTK_VERSION >= 2.11
- * static gboolean
-handle_tooltip_query (GtkWidget  *widget,
-                                         gint        x, gint        y,
-                                         GtkTooltip *tooltip,
-                                         gpointer    data)
-{
-    t_sensors *sensors;
-    gchar *buffer;
-
-    g_assert (data!=NULL);
-
-    sensors = (t_sensors *) data;
-
-    buffer = g_strdup("Tooltip placeholder");
-
-    gtk_tooltip_set_markup (tooltip, buffer);
-
-    return TRUE;
-} */
-
-
-
-
 static void
 sensors_free (XfcePanelPlugin *plugin, t_sensors *sensors)
 {
@@ -1278,14 +1243,15 @@ font_size_change (GtkWidget *widget, t_sensors_dialog *sd)
 {
     int rows;
     TRACE ("enters font_size_change");
-
+    
+    g_free(sd->sensors->font_size);
     switch ( gtk_combo_box_get_active(GTK_COMBO_BOX(widget)) ) {
 
-        case 0: sd->sensors->font_size = "x-small"; break;
-        case 1: sd->sensors->font_size = "small"; break;
-        case 3: sd->sensors->font_size = "large"; break;
-        case 4: sd->sensors->font_size = "x-large"; break;
-        default: sd->sensors->font_size = "medium";
+        case 0: sd->sensors->font_size = g_strdup("x-small"); break;
+        case 1: sd->sensors->font_size = g_strdup("small"); break;
+        case 3: sd->sensors->font_size = g_strdup("large"); break;
+        case 4: sd->sensors->font_size = g_strdup("x-large"); break;
+        default: sd->sensors->font_size = g_strdup("medium");
     }
 
     sd->sensors->font_size_numerical =
@@ -2215,13 +2181,8 @@ sensors_create_options (XfcePanelPlugin *plugin, t_sensors *sensors)
 
     add_sensors_frame (notebook, sd);
 
-    if (!tooltips)
-      tooltips = gtk_tooltips_new();
-
-    /* #if GTK_VERSION < 2.11 */
     myToolTipText = g_strdup(_("You can change a feature's properties such as name, colours, min/max value by double-clicking the entry, editing the content, and pressing \"Return\" or selecting a different field."));
-    gtk_tooltips_set_tip (tooltips, GTK_WIDGET(sd->myTreeView),
-                          myToolTipText, NULL);
+    gtk_widget_set_tooltip_text (GTK_WIDGET(sd->myTreeView), myToolTipText);
     g_free (myToolTipText);
     /* g_signal_connect (G_OBJECT (sd->myComboBox), "changed",
                       //G_CALLBACK (sensor_entry_changed), sd ); */
@@ -2282,7 +2243,7 @@ create_sensors_control (XfcePanelPlugin *plugin)
 
     add_event_box (sensors);
 
-        /* Add tooltip to show extended current sensors status */
+    /* Add tooltip to show extended current sensors status */
     sensors_create_tooltip ((gpointer) sensors);
 
     /* fill panel widget with boxes, strings, values, ... */
@@ -2292,12 +2253,6 @@ create_sensors_control (XfcePanelPlugin *plugin)
     gtk_container_add (GTK_CONTAINER (sensors->eventbox),
                        sensors->widget_sensors);
 
-    /* #if GTK_VERSION >= 2.11
-     * g_signal_connect(G_OBJECT(sensors->eventbox),
-                                    "query-tooltip",
-                                    G_CALLBACK(handle_tooltip_query),
-                                    (gpointer) sensors); */
-
     /* sensors_set_size (control, settings.size); */
 
     TRACE ("leaves create_sensors_control");
